@@ -226,6 +226,8 @@ class HttpTransport(Transport):
         }
         if self.compression == HttpCompression.GZIP:
             headers["Content-Encoding"] = "gzip"
-            return gzip.compress(event_str.encode("utf-8")), headers
+            # levels higher than 3 are twice as slow:
+            # https://github.com/python/cpython/issues/91349#issuecomment-2737161048
+            return gzip.compress(event_str.encode("utf-8"), compresslevel=3), headers
 
         return event_str, headers
