@@ -32,6 +32,7 @@ def test_client_uses_default_http_factory() -> None:
     assert isinstance(client.transport, HttpTransport)
     assert client.transport.url == "http://mock-url:5000"
     assert client.transport.endpoint == "endpoint"
+    assert client.transport.priority == 0
 
 
 def test_factory_registers_new_transports(mocker: MockerFixture, root: Path) -> None:
@@ -95,11 +96,14 @@ def test_factory_registers_from_dict(mocker: MockerFixture, root: Path) -> None:
         "accumulating",
         clazz="tests.transport.AccumulatingTransport",
     )
+    priority = 2
     config = {
         "type": "accumulating",
+        "priority": f"{priority}",
     }
     transport = factory.create(config=config)
     assert isinstance(transport, AccumulatingTransport)
+    assert transport.priority == priority
 
 
 def test_automatically_registers_http_kafka() -> None:
@@ -147,3 +151,92 @@ def test_env_disabled_ignores_config(mocker: MockerFixture, root: Path) -> None:
         clazz="tests.transport.FakeTransport",
     )
     assert isinstance(OpenLineageClient(factory=factory).transport, NoopTransport)
+
+
+def test_wrong_priority_raises_error() -> None:
+    factory = DefaultTransportFactory()
+    with pytest.raises(
+        ValueError, match="Error casting priority `non_int` to int for transport `doesnt_matter`"
+    ):
+        factory.create(
+            {
+                "type": "doesnt_matter",
+                "priority": "non_int",
+            }
+        )
+
+
+def test_priority_is_correctly_assigned() -> None:
+    factory = DefaultTransportFactory()
+    factory.register_transport(
+        "fake",
+        clazz="tests.transport.FakeTransport",
+    )
+    priority = 3
+    transport = factory.create(
+        {
+            "type": "fake",
+            "priority": f"{3}",
+        }
+    )
+    assert transport.kind == "fake"
+    assert transport.priority == priority
+
+
+def test_factory_create_transport_missing_type() -> None:
+    """Test error when transport type is missing from config."""
+    factory = DefaultTransportFactory()
+    config = {"url": "http://example.com"}  # Missing 'type' key
+
+    with pytest.raises(KeyError):
+        factory._create_transport(config)
+
+
+def test_factory_create_transport_invalid_transport_class() -> None:
+    """Test error when transport class is not a Transport subclass."""
+    factory = DefaultTransportFactory()
+
+    # Register a class that's not a Transport subclass
+    class NotATransport:
+        pass
+
+    factory.register_transport("invalid", NotATransport)
+    config = {"type": "invalid"}
+
+    with pytest.raises(TypeError, match="Transport .* has to be class, and subclass of Transport"):
+        factory._create_transport(config)
+
+
+def test_factory_create_transport_invalid_config_class() -> None:
+    """Test error when config class is not a Config subclass."""
+    from openlineage.client.transport import Transport
+
+    factory = DefaultTransportFactory()
+
+    # Create a transport with invalid config_class
+    class NotAConfig:
+        pass
+
+    class InvalidTransport(Transport):
+        config_class = NotAConfig
+
+        def emit(self, event):
+            pass
+
+    factory.register_transport("invalid_config", InvalidTransport)
+    config = {"type": "invalid_config"}
+
+    with pytest.raises(TypeError, match="Config .* has to be class, and subclass of Config"):
+        factory._create_transport(config)
+
+
+def test_factory_create_transport_with_name() -> None:
+    """Test transport creation with custom name."""
+    factory = DefaultTransportFactory()
+    factory.register_transport("accumulating", AccumulatingTransport)
+
+    config = {"type": "accumulating", "name": "my_transport"}
+    transport = factory._create_transport(config)
+
+    assert isinstance(transport, AccumulatingTransport)
+    assert transport.name == "my_transport"
